package bandeira;


import bandeira.desenho.CirculoDesenho;
import bandeira.desenho.DesenhoDecorator;
import bandeira.desenho.LosangoDesenho;
import bandeira.desenho.RetanguloDesenho;
import bandeira.desenho.TelaDesenho;
import java.awt.Color;
import java.awt.Graphics;
import javax.swing.JFrame;
import javax.swing.JPanel;

public class BandeiraMain extends JPanel {
    
    private final DesenhoDecorator desenho;
    
    public BandeiraMain( DesenhoDecorator desenho ) {
        this.desenho = desenho;                            
    }
    
    @Override
    public void paintComponent( Graphics g ) {
        super.paintComponent( g );
        
        int w = super.getWidth();
        int h = super.getHeight();        
        desenho.desenha( g, w, h );         
    }
    
    public static void main( String[] args ) {
        DesenhoDecorator decorator = new TelaDesenho();
        decorator = new RetanguloDesenho( decorator, 300, 250, Color.GREEN );
        decorator = new LosangoDesenho( decorator, 280, 230, Color.YELLOW );
        decorator = new CirculoDesenho( decorator, 75, Color.BLUE );        
        
        JPanel desenhoPainel = new BandeiraMain( decorator );
        
        JFrame f = new JFrame();
        f.setContentPane( desenhoPainel );
        f.setTitle( "Desenhando com decorator pattern" ); 
        f.setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE );
        f.setSize( 400, 400 );
        f.setLocationRelativeTo( f );  
        f.setVisible( true );
    }
    
}
